summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Master/tlpkg/TeXLive/TLUtils.pm9
1 files changed, 5 insertions, 4 deletions
diff --git a/Master/tlpkg/TeXLive/TLUtils.pm b/Master/tlpkg/TeXLive/TLUtils.pm
index 6af3f1e4dbc..ee004737b29 100644
--- a/Master/tlpkg/TeXLive/TLUtils.pm
+++ b/Master/tlpkg/TeXLive/TLUtils.pm
@@ -266,10 +266,11 @@ sub platform_name {
my $CPU; # CPU type as reported by config.guess.
my $OS; # O/S type as reported by config.guess.
($CPU = $guessed_platform) =~ s/(.*?)-.*/$1/;
- $CPU =~ s/^alpha(.*)/alpha/; # alphaev56 or whatever
- $CPU =~ s/armv7l/armel/; # arm
- $CPU =~ s/powerpc64/powerpc/; # we don't distinguish ppc64
- $CPU =~ s/mips64el/mipsel/; # we don't distinguish mips64 and 32 el
+ $CPU =~ s/^alpha(.*)/alpha/; # alphaev whatever
+ $CPU =~ s/armv7l/armel/; # arm whatever
+ $CPU =~ s/powerpc64/powerpc/; # don't distinguish ppc64
+ $CPU =~ s/sparc64/sparc/; # don't distinguish sparc64
+ $CPU =~ s/mips64el/mipsel/; # don't distinguish mips64 and 32 el
my @OSs = qw(aix cygwin darwin freebsd hpux irix
kfreebsd linux netbsd openbsd solaris);